<?php
namespace Pushpro\Pushpro\Controller;

/***
 *
 * This file is part of the "pushpro" Extension for TYPO3 CMS.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 *
 *  (c) 2020
 *
 ***/

/**
 * PushproTokenController
 */

use Pushpro\Pushpro\Service\ApiCall;
use Pushpro\Pushpro\Domain\Repository\PushproTokenRepository;

class PushproTokenController extends \TYPO3\CMS\Extbase\Mvc\Controller\ActionController
{

    /**
     * PushproTokenController constructor.
     *
     * @param  \Pushpro\Pushpro\Service\ApiCall  $apiCall
     * @param  \Pushpro\Pushpro\Domain\Repository\PushproTokenRepository  $pushproTokenRepository
     */
    public function __construct(ApiCall $apiCall, PushproTokenRepository $pushproTokenRepository, $p = null)
    {
        //        parent::__construct();
        $this->apiCall = $apiCall;
        $this->pushproTokenRepository = $pushproTokenRepository;
    }

    /**
     * action list
     *
     * @return void
     */
    public function listAction()
    {

        $pushproTokens = $this->pushproTokenRepository->countRecords();
        $token = '';
        if($pushproTokens){
            $pushproTokens = $this->pushproTokenRepository->getRecord();
            $token = $this->pushproTokenRepository->getToken();
        }

        $this->view->assign('pushproTokens', $pushproTokens);
        $this->view->assign('pushproTokenStats', json_encode($this->apiCall->setApiKey($token)->stats()));

    }

    /**
     * action show
     *
     * @param array $pushproToken
     * @return void
     */
    public function showAction($pushproToken)
    {
        $pushproToken = $this->pushproTokenRepository->findByUid($pushproToken['uid']);
        $this->view->assign('pushproToken', $pushproToken);
    }

    /**
     * action create
     *
     * @param \Pushpro\Pushpro\Domain\Model\PushproToken $newPushproToken
     * @return void
     */
    public function createAction(\Pushpro\Pushpro\Domain\Model\PushproToken $newPushproToken)
    {
        $pushproTokens = $this->pushproTokenRepository->countRecords();
        if($pushproTokens){
            $this->redirect('list');
        }else{
            $strToken = $newPushproToken->getToken();
            if(strlen($strToken) != 64){
                $this->addFlashMessage('Token must contain 64 symbols', '', \TYPO3\CMS\Core\Messaging\AbstractMessage::WARNING);
            }else{
                $newPushproToken->setPid(0);
                $this->pushproTokenRepository->add($newPushproToken);
            }
            $this->redirect('list');
        }

    }

    /**
     * action edit
     *
     * @param array $pushproToken
     * @return void
     */
    public function editAction($pushproToken)
    {
        $pushproToken = $this->pushproTokenRepository->findByUid($pushproToken['uid']);
        $this->view->assign('pushproToken', $pushproToken);
    }

    /**
     * action update
     *
     * @param \Pushpro\Pushpro\Domain\Model\PushproToken $newPushproToken
     * @return void
     */
    public function updateAction( $pushproToken)
    {
        $strToken = $pushproToken->getToken();
        if(strlen($strToken) != 64){
            $this->addFlashMessage('Token must contain 64 symbols', '', \TYPO3\CMS\Core\Messaging\AbstractMessage::WARNING);
        }else{
            $this->pushproTokenRepository->update($pushproToken);
        }
        $this->redirect('list');

    }

    /**
     * action delete
     *
     * @param array $pushproToken
     * @return void
     */
    public function deleteAction( $pushproToken)
    {
        $pushproToken = $this->pushproTokenRepository->findByUid($pushproToken['uid']);
        $this->pushproTokenRepository->remove($pushproToken);
        $this->redirect('list');
    }

}
