<?php
namespace Pushpro\Pushpro\Service;
use TYPO3\CMS\Core\Http\RequestFactory;

class ApiCall
{

    protected $baseUrl = 'https://portal.pushpro.io/';

    protected $apiPartUrl = 'api/v1/extension/';

    protected $checkUrl = 'check/';

    protected $snippetUrl = 'snippet/';

    protected $statsUrl = 'stats/';

    const REQUEST = 'GET';

    /** @var RequestFactory */
    private $requestFactory;

    protected $apiKey = '';


    // Initiate the Request Factory, which allows to run multiple requests (prefer dependency injection)
    /**
     * PushproTokenController constructor.
     *
     * @param  \TYPO3\CMS\Core\Http\RequestFactory  $requestFactory

     */
    public function __construct(RequestFactory $requestFactory)
    {
        $this->requestFactory = $requestFactory;

    }

    public function setApiKey($token){
        $this->apiKey = $token;
        return $this;
    }

    public function makeRequest(
        $url,
        $data = [],
        $type = 'GET',
        $options = []
    ) {
        try {
            $response = $this->requestFactory->request($url, 'GET', $options);
            return $this->sendResponseAsObject($response);
        } catch (\Exception $e) {

            return null;
        }
    }

    protected function sendResponseAsObject($response)
    {
        $statusCode = $response->getStatusCode();
        if ($statusCode === 200) {
            return json_decode((string) $response->getBody());
        }

        return null;
    }

    public function getFullApiUrl()
    {
        return $this->baseUrl.$this->apiPartUrl;
    }

    public function getRequestUrl($urlPart)
    {
        return $this->getFullApiUrl().$urlPart;
    }

    public function check()
    {
        return $this->makeRequest($this->getRequestUrl($this->checkUrl)
                                  .$this->apiKey,
          [], $this::REQUEST, []);
    }

    public function snippet()
    {
        return $this->makeRequest($this->getRequestUrl($this->snippetUrl)
                                  .$this->apiKey,
            [], $this::REQUEST, []);
    }

    public function stats()
    {
        return $this->makeRequest($this->getRequestUrl($this->statsUrl)
                                  .$this->apiKey,
             [], $this::REQUEST, []);
    }

}
