<?php
namespace Pushpro\Pushpro\Tests\Unit\Controller;

/**
 * Test case.
 */
class PushproTokenControllerTest extends \TYPO3\CMS\Core\Tests\UnitTestCase
{
    /**
     * @var \Pushpro\Pushpro\Controller\PushproTokenController
     */
    protected $subject = null;

    protected function setUp()
    {
        parent::setUp();
        $this->subject = $this->getMockBuilder(\Pushpro\Pushpro\Controller\PushproTokenController::class)
            ->setMethods(['redirect', 'forward', 'addFlashMessage'])
            ->disableOriginalConstructor()
            ->getMock();
    }

    protected function tearDown()
    {
        parent::tearDown();
    }

    /**
     * @test
     */
    public function listActionFetchesAllPushproTokensFromRepositoryAndAssignsThemToView()
    {

        $allPushproTokens = $this->getMockBuilder(\TYPO3\CMS\Extbase\Persistence\ObjectStorage::class)
            ->disableOriginalConstructor()
            ->getMock();

        $pushproTokenRepository = $this->getMockBuilder(\Pushpro\Pushpro\Domain\Repository\PushproTokenRepository::class)
            ->setMethods(['findAll'])
            ->disableOriginalConstructor()
            ->getMock();
        $pushproTokenRepository->expects(self::once())->method('findAll')->will(self::returnValue($allPushproTokens));
        $this->inject($this->subject, 'pushproTokenRepository', $pushproTokenRepository);

        $view = $this->getMockBuilder(\TYPO3\CMS\Extbase\Mvc\View\ViewInterface::class)->getMock();
        $view->expects(self::once())->method('assign')->with('pushproTokens', $allPushproTokens);
        $this->inject($this->subject, 'view', $view);

        $this->subject->listAction();
    }

    /**
     * @test
     */
    public function showActionAssignsTheGivenPushproTokenToView()
    {
        $pushproToken = new \Pushpro\Pushpro\Domain\Model\PushproToken();

        $view = $this->getMockBuilder(\TYPO3\CMS\Extbase\Mvc\View\ViewInterface::class)->getMock();
        $this->inject($this->subject, 'view', $view);
        $view->expects(self::once())->method('assign')->with('pushproToken', $pushproToken);

        $this->subject->showAction($pushproToken);
    }

    /**
     * @test
     */
    public function createActionAddsTheGivenPushproTokenToPushproTokenRepository()
    {
        $pushproToken = new \Pushpro\Pushpro\Domain\Model\PushproToken();

        $pushproTokenRepository = $this->getMockBuilder(\Pushpro\Pushpro\Domain\Repository\PushproTokenRepository::class)
            ->setMethods(['add'])
            ->disableOriginalConstructor()
            ->getMock();

        $pushproTokenRepository->expects(self::once())->method('add')->with($pushproToken);
        $this->inject($this->subject, 'pushproTokenRepository', $pushproTokenRepository);

        $this->subject->createAction($pushproToken);
    }

    /**
     * @test
     */
    public function editActionAssignsTheGivenPushproTokenToView()
    {
        $pushproToken = new \Pushpro\Pushpro\Domain\Model\PushproToken();

        $view = $this->getMockBuilder(\TYPO3\CMS\Extbase\Mvc\View\ViewInterface::class)->getMock();
        $this->inject($this->subject, 'view', $view);
        $view->expects(self::once())->method('assign')->with('pushproToken', $pushproToken);

        $this->subject->editAction($pushproToken);
    }

    /**
     * @test
     */
    public function updateActionUpdatesTheGivenPushproTokenInPushproTokenRepository()
    {
        $pushproToken = new \Pushpro\Pushpro\Domain\Model\PushproToken();

        $pushproTokenRepository = $this->getMockBuilder(\Pushpro\Pushpro\Domain\Repository\PushproTokenRepository::class)
            ->setMethods(['update'])
            ->disableOriginalConstructor()
            ->getMock();

        $pushproTokenRepository->expects(self::once())->method('update')->with($pushproToken);
        $this->inject($this->subject, 'pushproTokenRepository', $pushproTokenRepository);

        $this->subject->updateAction($pushproToken);
    }

    /**
     * @test
     */
    public function deleteActionRemovesTheGivenPushproTokenFromPushproTokenRepository()
    {
        $pushproToken = new \Pushpro\Pushpro\Domain\Model\PushproToken();

        $pushproTokenRepository = $this->getMockBuilder(\Pushpro\Pushpro\Domain\Repository\PushproTokenRepository::class)
            ->setMethods(['remove'])
            ->disableOriginalConstructor()
            ->getMock();

        $pushproTokenRepository->expects(self::once())->method('remove')->with($pushproToken);
        $this->inject($this->subject, 'pushproTokenRepository', $pushproTokenRepository);

        $this->subject->deleteAction($pushproToken);
    }
}
